@@ -249,6 +249,7 @@ var NAVTREE =
       [ "\\date { date description }", "commands.html#cmddate", null ],
       [ "\\deprecated { description }", "commands.html#cmddeprecated", null ],
       [ "\\details { detailed description }", "commands.html#cmddetails", null ],
+      [ "\\noop ( text to be ignored )", "commands.html#cmdnoop", null ],
       [ "\\else", "commands.html#cmdelse", null ],
       [ "\\elseif (section-label)", "commands.html#cmdelseif", null ],
       [ "\\endcond", "commands.html#cmdendcond", null ],
@@ -391,6 +392,7 @@ var NAVTREE =
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
       [ "1.8 Series", "changelog.html#log_1_8", [
+        [ "Release 1.8.17", "changelog.html#log_1_8_17", null ],
         [ "Release 1.8.16", "changelog.html#log_1_8_16", null ],
         [ "Release 1.8.15", "changelog.html#log_1_8_15", null ],
         [ "Release 1.8.14", "changelog.html#log_1_8_14", null ],
@@ -427,7 +429,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"custcmd.html#custcmd_nesting"
+"custcmd.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
